@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.040000";
+$VERSION = "5.040001";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.40.0) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.40.1) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.40.0
-    or die sprintf "%s: Perl lib version (5.40.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.40.1
+    or die sprintf "%s: Perl lib version (5.40.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -98,7 +98,7 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib',
     osname => 'linux',
-    osvers => '6.1.0-17-amd64',
+    osvers => '6.12.10-gentoo-dist',
     path_sep => ':',
     privlibexp => '/usr/lib64/perl5/5.40',
     scriptdir => '/usr/bin',
@@ -107,5 +107,5 @@ tie %Config, 'Config', {
     so => 'so',
     useithreads => undef,
     usevendorprefix => 'define',
-    version => '5.40.0',
+    version => '5.40.1',
 };
